#!/usr/bin/ruby
#
# Sensu Handler: mailjet
#
# This handler formats alerts and sends them off to the mailjet sms gateway.
#
# Copyright 2020 Stefan Walluhn, about source GmbH
#
# Released under the same terms as Sensu (the MIT license); see LICENSE
# for details.

require 'sensu-handler'
require 'timeout'
require 'rest-client'

class HandlerMailjet < Sensu::Handler
  def handle
    apiurl = settings['mailjet']['sms_url'] || 'https://api.mailjet.com/v4/sms-send',
    auth_token = settings['mailjet']['auth_token']
    phone_numbers = settings['mailjet']['phone_numbers']

    phone_numbers.each do |phone_number|
        response = RestClient.post(
            'https://api.mailjet.com/v4/sms-send',
            payload(phone_number, message()),
            {
                content_type: :json,
                authorization: "Bearer #{auth_token}",
            },
        )

        puts format('sent alert %<message>s to number %<number>s',
                     message: message(),
                     number: phone_number
                   )

        puts format('response: %<response_code>d %<response_body>s',
                    response_code: response.code,
                    response_body: response.body
                   )
    end
  end

  private
  def message()
    format('%<message>0.159s',
           message: [
               @event['client']['name'],
               @event['check']['name'],
               @event['check']['output']
           ].join(' - '))
  end

  def payload(phonenumber, message)
      {
          'Text' => message,
          'To' => phonenumber,
          'From' => 'Sensu',
      }.to_json
  end
end

